.. dowhy documentation master file, created by
   sphinx-quickstart on Tue Mar 13 14:48:10 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: getting_started/intro.rst

.. toctree::
   :hidden: 
   :maxdepth: 2
   :caption: Getting Started
   
   Introduction to DoWhy <getting_started/intro>
   getting_started/install
   Quick-start notebook <example_notebooks/dowhy_simple_example>
   Comparison to other packages <getting_started/comparison>
   getting_started/cite

.. toctree::
   :hidden: 
   :maxdepth: 2
   :caption: User Guide

   user_guide/causality_intro
   user_guide/effect_inference/index
   user_guide/gcm_based_inference/index
   example_notebooks/nb_index

.. toctree::
   :hidden: 
   :maxdepth: 2
   :caption: Tutorials/Case studies

   CATE estimation with DoWhy+EconML <example_notebooks/tutorial-causalinference-machinelearning-using-dowhy-econml>
   example_notebooks/nb_casestudies_index

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Contributing

   contributing/index

.. toctree::
   :hidden: 
   :maxdepth: 2
   :caption: Package

   code_repo
   dowhy
